@@ -34,7 +34,13 @@ class TinyMCE(TextArea):
     </span>
     """
     langs = utils.get_available_languages()
-    params = ["mce_options"]
+    params = ["mce_options", "new_options"]
+    params_doc = {
+            'mce_options' : _("Options to initialize TinyMCE's javascript. This"
+                              " dict will override the defaults"),
+            'new_options' : _("Options to initialize TinyMCE's javascript. This"
+                              " dict will update the defaults"),
+            }
     rows = 25
     mce_options = dict(
         mode = "exact",
@@ -50,6 +56,7 @@ class TinyMCE(TextArea):
         paste_convert_headers_to_strong = False,
         paste_strip_class_attributes = "all",
     )
+    new_options = {}
     validator = utils.HTMLCleaner()
     javascript = [JSLink("tinymce", "tiny_mce_src.js")]
 
@@ -73,10 +80,12 @@ class TinyMCE(TextArea):
 
     def update_params(self, d):
         super(TinyMCE, self).update_params(d)
+        d['mce_options'].update(d['new_options'])
         locale = self._get_locale()
         if locale:
             d['mce_options'].setdefault('language', locale)
-        d['mce_options']['elements'] = d['field_id']
+        if d['mce_options'].get('mode', 'textareas') == 'exact':
+            d['mce_options']['elements'] = d['field_id']
         d['TinyMCEInit'] = "tinyMCE.init(%s);" % encode(d['mce_options'])
 
 
